==> restful-1.51.57-sources.jar: com/aote/rs/VueService.java <==
package com.aote.rs;

import com.aote.ThreadResource;
import com.aote.exception.FileNotFoundException;
import com.aote.logic.LogicServer;
import com.aote.rs.mapper.WebException;
import com.aote.util.ResourceHelper;
import com.aote.v4.compatibility.liuli.config.service.LiuLiConfigService;
import org.apache.log4j.Logger;
import org.json.JSONArray;
import org.json.JSONObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import javax.inject.Singleton;
import javax.ws.rs.*;
import java.io.*;
import java.net.URL;
import java.nio.charset.StandardCharsets;


@Path("vue")
@Singleton
@Component
public class VueService {

    @Autowired
    private LiuLiConfigService liuLiConfigService;
    /**
     * 执行业务逻辑(GET方式)
     *
     * @param  vueName 业务逻辑名称
     * @param folderName 文件夹名称
     * @return 执行结果
     */
    @GET
    @Transactional
    @Path("{vue}")
    public String getVueConfig(@PathParam("vue") String vueName, @QueryParam("folderName") String folderName)throws Exception {
        JSONObject vueConfig = null;
        try {
            // 获取后缀名之前的内容
            vueConfig = liuLiConfigService.get(vueName.substring(0, vueName.indexOf(".")));
        } catch (Exception e){
            e.printStackTrace();
        }
        if(vueConfig != null){
            return vueConfig.toString();
        }
        String dir = ThreadResource.ComponentDir.get();
        if (dir == null) {
            // 把文件不存在异常转换成704错误状态
            throw new WebException(704, "用户没有特殊目录！");
        }
        String path;
        // 没传文件夹名称, 默认取vues文件夹下的配置
        if (folderName == null) {
            //查看对应目录下是否存在相关vue
            path = dir + "/vues/" +vueName;
        } else {
            path = dir + "/" + folderName + "/" + vueName;
        }

        try {
            return ResourceHelper.getString(path);
        } catch (FileNotFoundException e) {
            // 把文件不存在异常转换成704错误状态
            throw new WebException(704, "文件不存在：" + e.getPath());
        }
    }

    @GET
    @Transactional
    public String getPhoneVueConfig() throws Exception{
        JSONObject vueConfig = null;
        try {
            // 获取后缀名之前的内容
            vueConfig = liuLiConfigService.getAll();
        } catch (Exception e){
            e.printStackTrace();
        }
        if(vueConfig != null){
            return vueConfig.toString();
        }
        JSONObject jsons = new JSONObject();
        String dir = ThreadResource.ComponentDir.get();
        if (dir == null || "".equals(dir)){
            throw new WebException(704, "用户没有特殊目录！");
        }
        try {
            //获取目录下所有文件名
            URL url = this.getClass().getClassLoader().getResource(dir +"/phonevues/");
            if (url == null) {
                url = this.getClass().getClassLoader().getResource("phonevues/");
            }
            String path = url.getPath();
            File[] files = new File(path).listFiles();
            if (files != null) {
                for (File f :files){
                    //读取文件内容
                    String fileName = f.getName();
                    StringBuilder strbuffer = new StringBuilder();
                    FileInputStream fis = new FileInputStream(f);
                    InputStreamReader inputStreamReader = new InputStreamReader(fis, StandardCharsets.UTF_8);
                    BufferedReader in  = new BufferedReader(inputStreamReader);
                    String str;
                    while ((str = in.readLine()) != null) {
                        strbuffer.append(str);
                    }
                    in.close();
                    //将文件内容转为json并保存
                    JSONObject json = new JSONObject(strbuffer.toString().trim());
                        jsons.put(fileName.substring(0,fileName.indexOf(".")),json);
                }
            }
            return jsons.toString();
        }catch (FileNotFoundException e){
            throw new WebException(704, "文件不存在: "+e.getPath());
        }
    }

    /**
     * 保存json
     *
     * @param value {path: '文件路径', data: 'json字符串'}
     * @return 结果
     * @throws Exception
     */
    @POST
    @Path("saveVueConfig")
    public String saveVueConfig(String value) {
        String path = null;
        String data;
        File file;
        try {
            JSONObject json = new JSONObject(value);
            path = String.valueOf(json.get("path"));
            data = formatJson(String.valueOf(json.get("data")));
            URL url = getClass().getClassLoader().getResource(path);
            file = new File(url.getFile());
            try (
                    FileOutputStream fos = new FileOutputStream(file);
                    OutputStreamWriter osw = new OutputStreamWriter(fos, StandardCharsets.UTF_8);
                    BufferedWriter b = new BufferedWriter(osw)
            ) {
                b.write(data);
                b.flush();
                return file.getAbsolutePath();
            }
        } catch (Exception e) {
            throw new WebException(500, "保存文件失败: " + path + "=>" + e);
        }

    }

    /**
     * 格式化json字符串
     * @param jsonStr json字符串
     * @return 格式化后的json字符串
     */
    public static String formatJson(String jsonStr) {
        if (null == jsonStr || "".equals(jsonStr)) return "";
        StringBuilder sb = new StringBuilder();
        char last;
        char current = '\0';
        int indent = 0;
        for (int i = 0; i < jsonStr.length(); i++) {
            last = current;
            current = jsonStr.charAt(i);
            switch (current) {
                case '{':
                case '[':
                    sb.append(current);
                    sb.append('\n');
                    indent++;
                    addIndentBlank(sb, indent);
                    break;
                case '}':
                case ']':
                    sb.append('\n');
                    indent--;
                    addIndentBlank(sb, indent);
                    sb.append(current);
                    break;
                case ',':
                    sb.append(current);
                    if (last != '\\') {
                        sb.append('\n');
                        addIndentBlank(sb, indent);
                    }
                    break;
                default:
                    sb.append(current);
            }
        }
        return sb.toString();
    }

    /**
     * 添加space
     *
     * @param sb
     * @param indent
     */
    public static void addIndentBlank(StringBuilder sb, int indent) {
        for (int i = 0; i < indent; i++) {
            sb.append('\t');
        }
    }
}

==> restful-1.54.7-sources.jar: com/aote/rs/VueService.java <==
package com.aote.rs;

import com.aote.ThreadResource;
import com.aote.exception.FileNotFoundException;
import com.aote.logic.LogicServer;
import com.aote.rs.mapper.WebException;
import com.aote.util.ResourceHelper;
import com.aote.v4.compatibility.liuli.config.service.LiuLiConfigService;
import org.apache.log4j.Logger;
import org.json.JSONArray;
import org.json.JSONObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import javax.inject.Singleton;
import javax.ws.rs.*;
import javax.ws.rs.core.Response;
import java.io.*;
import java.net.URL;
import java.nio.charset.StandardCharsets;


@Path("vue")
@Singleton
@Component
public class VueService {

    @Autowired
    private LiuLiConfigService liuLiConfigService;

    @GET
    @Transactional
    public String getPhoneVueConfig() throws Exception{
        JSONObject vueConfig = null;
        try {
            // 获取后缀名之前的内容
            vueConfig = liuLiConfigService.getByModule("旧Vue配置迁移");
        } catch (Exception e){
            e.printStackTrace();
        }
        if(vueConfig != null){
            return vueConfig.toString();
        }
        JSONObject jsons = new JSONObject();
        String dir = ThreadResource.ComponentDir.get();
        if (dir == null || "".equals(dir)){
            throw new WebException(704, "用户没有特殊目录！");
        }
        try {
            //获取目录下所有文件名
            URL url = this.getClass().getClassLoader().getResource(dir +"/phonevues/");
            if (url == null) {
                url = this.getClass().getClassLoader().getResource("phonevues/");
            }
            String path = url.getPath();
            File[] files = new File(path).listFiles();
            if (files != null) {
                for (File f :files){
                    //读取文件内容
                    String fileName = f.getName();
                    StringBuilder strbuffer = new StringBuilder();
                    FileInputStream fis = new FileInputStream(f);
                    InputStreamReader inputStreamReader = new InputStreamReader(fis, StandardCharsets.UTF_8);
                    BufferedReader in  = new BufferedReader(inputStreamReader);
                    String str;
                    while ((str = in.readLine()) != null) {
                        strbuffer.append(str);
                    }
                    in.close();
                    //将文件内容转为json并保存
                    JSONObject json = new JSONObject(strbuffer.toString().trim());
                    jsons.put(fileName.substring(0,fileName.indexOf(".")),json);
                }
            }
            return jsons.toString();
        }catch (FileNotFoundException e){
            throw new WebException(704, "文件不存在: "+e.getPath());
        }
    }

    @GET
    @Transactional
    @Path("/")
    public String getPhoneVueConfig2() throws Exception {
        return getPhoneVueConfig();
    }

    @GET
    @Transactional
    @Path("/{vue}")
    public String getVueConfig(@PathParam("vue") String vueName, @QueryParam("folderName") String folderName)throws Exception {
        JSONObject vueConfig = null;
        try {
            // 获取后缀名之前的内容
            vueConfig = liuLiConfigService.get(vueName.substring(0, vueName.indexOf(".")));
        } catch (Exception e){
            e.printStackTrace();
        }
        if(vueConfig != null){
            return vueConfig.toString();
        }
        String dir = ThreadResource.ComponentDir.get();
        if (dir == null) {
            // 把文件不存在异常转换成704错误状态
            throw new WebException(704, "用户没有特殊目录！");
        }
        String path;
        // 没传文件夹名称, 默认取vues文件夹下的配置
        if (folderName == null) {
            //查看对应目录下是否存在相关vue
            path = dir + "/vues/" +vueName;
        } else {
            path = dir + "/" + folderName + "/" + vueName;
        }

        try {
            return ResourceHelper.getString(path);
        } catch (FileNotFoundException e) {
            // 把文件不存在异常转换成704错误状态
            throw new WebException(704, "文件不存在：" + e.getPath());
        }
    }

    /**
     * 保存json
     *
     * @param value {path: '文件路径', data: 'json字符串'}
     * @return 结果
     * @throws Exception
     */
    @POST
    @Path("saveVueConfig")
    public String saveVueConfig(String value) {
        String path = null;
        String data;
        File file;
        try {
            JSONObject json = new JSONObject(value);
            path = String.valueOf(json.get("path"));
            data = formatJson(String.valueOf(json.get("data")));
            URL url = getClass().getClassLoader().getResource(path);
            file = new File(url.getFile());
            try (
                    FileOutputStream fos = new FileOutputStream(file);
                    OutputStreamWriter osw = new OutputStreamWriter(fos, StandardCharsets.UTF_8);
                    BufferedWriter b = new BufferedWriter(osw)
            ) {
                b.write(data);
                b.flush();
                return file.getAbsolutePath();
            }
        } catch (Exception e) {
            throw new WebException(500, "保存文件失败: " + path + "=>" + e);
        }

    }

    /**
     * 格式化json字符串
     * @param jsonStr json字符串
     * @return 格式化后的json字符串
     */
    public static String formatJson(String jsonStr) {
        if (null == jsonStr || "".equals(jsonStr)) return "";
        StringBuilder sb = new StringBuilder();
        char last;
        char current = '\0';
        int indent = 0;
        for (int i = 0; i < jsonStr.length(); i++) {
            last = current;
            current = jsonStr.charAt(i);
            switch (current) {
                case '{':
                case '[':
                    sb.append(current);
                    sb.append('\n');
                    indent++;
                    addIndentBlank(sb, indent);
                    break;
                case '}':
                case ']':
                    sb.append('\n');
                    indent--;
                    addIndentBlank(sb, indent);
                    sb.append(current);
                    break;
                case ',':
                    sb.append(current);
                    if (last != '\\') {
                        sb.append('\n');
                        addIndentBlank(sb, indent);
                    }
                    break;
                default:
                    sb.append(current);
            }
        }
        return sb.toString();
    }

    /**
     * 添加space
     *
     * @param sb
     * @param indent
     */
    public static void addIndentBlank(StringBuilder sb, int indent) {
        for (int i = 0; i < indent; i++) {
            sb.append('\t');
        }
    }
}
